/* Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */

package org.dive4elements.river.model.sinfo;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.OneToMany;
import javax.persistence.OneToOne;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;

import org.dive4elements.river.model.AnnotationType;
import org.dive4elements.river.model.River;

/**
 * Hibernate binding for the DB table infrastructure
 *
 * @author Matthias Schäfer
 *
 */

@Entity
@Table(name = "infrastructure")
public class Infrastructure implements Serializable {

    /***** FIELDS *****/

    private static final long serialVersionUID = -5505080011501611034L;

    private Integer id;

    private River river;

    private String filename;

    private String kmrange_info;

    private String notes;

    private AnnotationType type;

    private Integer year;

    private String dataprovider;

    private String evaluation_by;

    private List<InfrastructureValue> values;


    /***** CONSTRUCTORS *****/

    public Infrastructure() {
    }


    public Infrastructure(final River river, final String filename, final String kmrange_info, final String notes, final AnnotationType type,
            final Integer year,
            final String dataprovider, final String evaluation_by) {
        this.river = river;
        this.filename = filename;
        this.kmrange_info = kmrange_info;
        this.notes = notes;
        this.type = type;
        this.year = year;
        this.dataprovider = dataprovider;
        this.evaluation_by = evaluation_by;
        this.values = new ArrayList<>();
    }

    /***** METHODS *****/

    @Id
    @SequenceGenerator(name = "SEQUENCE_INFRASTRUCTURE_ID_SEQ", sequenceName = "INFRASTRUCTURE_ID_SEQ", allocationSize = 1)
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "SEQUENCE_INFRASTRUCTURE_ID_SEQ")
    @Column(name = "id")
    public Integer getId() {
        return this.id;
    }

    public void setId(final Integer id) {
        this.id = id;
    }

    @OneToOne
    @JoinColumn(name = "river_id")
    public River getRiver() {
        return this.river;
    }

    public void setRiver(final River river) {
        this.river = river;
    }

    @Column(name = "filename")
    public String getFilename() {
        return this.filename;
    }

    public void setFilename(final String filename) {
        this.filename = filename;
    }

    @Column(name = "kmrange_info")
    public String getKmrange_info() {
        return this.kmrange_info;
    }

    public void setKmrange_info(final String kmrange_info) {
        this.kmrange_info = kmrange_info;
    }

    @Column(name = "notes")
    public String getNotes() {
        return this.notes;
    }

    public void setNotes(final String notes) {
        this.notes = notes;
    }

    @OneToOne
    @JoinColumn(name = "annotation_type_id")
    public AnnotationType getType() {
        return this.type;
    }

    public void setType(final AnnotationType type) {
        this.type = type;
    }

    @Column(name = "year")
    public Integer getYear() {
        return this.year;
    }

    public void setYear(final Integer year) {
        this.year = year;
    }

    @Column(name = "dataprovider")
    public String getDataprovider() {
        return this.dataprovider;
    }

    public void setDataprovider(final String dataprovider) {
        this.dataprovider = dataprovider;
    }

    @Column(name = "evaluation_by")
    public String getEvaluation_by() {
        return this.evaluation_by;
    }

    public void setEvaluation_by(final String evaluation_by) {
        this.evaluation_by = evaluation_by;
    }

    @OneToMany
    @JoinColumn(name = "infrastructure_id")
    public List<InfrastructureValue> getValues() {
        return this.values;
    }

    public void setValues(final List<InfrastructureValue> values) {
        this.values = values;
    }

    public void addValue(final InfrastructureValue value) {
        this.values.add(value);
    }
}